﻿/*●●●日本語エスペラント辞典ページ画像検索プログラム
File	NiesV01.js
Date	2012-12-18---2013-07-31; 2013-11-15
Copyright (C) 2012,2013, Tositaka Teramoto & Fukumoto Hirotsugu
 Permission to use, copy, modify, distribute and sell this software
 and its documentation for any purpose is hereby granted without fee,
 provided that the above copyright notice appear in all copies and
 that both that copyright notice and this permission notice appear
 in supporting documentation. 
 This file is provided "as is" without express or implied warranty.
*/

//

window.onload= function() {
	font_egala();
	scale();
	if ( g_hideList=="Y" ) {
		showSearchPane();
	}
	document.getElementById("searchstr").focus();

	addEventHandler(document.getElementById("pageimg"), "mousedown", Img_OnMouse_down);
	addEventHandler(document.getElementById("pageimg"), "mousemove", Img_OnMouse_move);
	addEventHandler(document.getElementById("results"), "click", showArticle);
	addEventHandler(document.getElementById("searchstr"), "keypress", inputSearchStr);
	addEventHandler(document.getElementById("page"), "keypress", inputPagePress);
	//
	var imgs=document.getElementsByTagName("img");
	for (var i=0; i<imgs.length; ++i) {
		if (imgs[i].className=="button") {
			addEventHandler(imgs[i], "mouseover", showTip);
			addEventHandler(imgs[i], "mouseout", hideTip);
		}
	}
	var inistr=document.getElementById("searchstr").value;
	if (inistr.length > 0) { 
		inputSearchStr();
	}

	setPagingClickRange();
}

window.onresize= function() {
	setPagingClickRange();
}

//画像ペインで、前/次ページのクリック可能範囲を設定
var o_x_prev=400;
var o_x_next=600;

function setPagingClickRange() {
	var width_body= window.innerWidth;	//NOTE !!
	if (!width_body)
		return;
	var width_img = parseInt(document.getElementById("pageimg").width);
	var isSplit= document.getElementById("results").style.display != "none";
	var offset= (isSplit)? g_ListWidth+12 : 5;
	width_body -= offset;
	var width= Math.min(width_body, width_img);
	o_x_prev= Math.round(width/3) + offset;
	o_x_next= Math.round(width/3*2) + offset;
}

//検索結果の1つをクリックした時、本文画像を表示
function showArticle(event) {
	var target;
	if (window.event)
		target= window.event.srcElement;
	else
		target= event.target;
	var page= target.getAttribute("params");
	if (parseInt(page)==0)
		return;
	var pageLR= "";
	if (!g_wholePage) {
		var pos= page.length-1;
		pageLR= page.substring(pos);
		page= page.substring(0, pos);
		setPageLR(pageLR);
	}
	setPage(page);

	var img=document.getElementById("pageimg");
	img.src= pageImgFilename(page, pageLR);
	imageOnShow();
}

////
function formatNumb(numb, digits) {
	return fillZeros(numb.toString(), digits);
}
function fillZeros(str, digits) {
	while (str.length<digits) {
		str= "0"+str;
	}
	return str;	
}
function removeZeros(str) {
	str=str+"";//こうしないとエラーの場合があった？
	while (str.charAt(0)=='0') {
		str= str.substring(1);
	}
	return str;
}

//辞書検索、表示

function search() {
	o_inptimer=null;	//NOTE !!

	var schstr= document.getElementById("searchstr").value;
	var results=document.getElementById("results");
	results.innerHTML="";

	//一覧の見出文字を作成
	var page_ichi;
	var title;
	if ( schstr=="") {
		// No list
		title="検索結果一覧";
		page_ichi=0;
	}
	else if (schstr==" ") {
		title="全ページ一覧";
		page_ichi=-1;
	}
	else if (schstr=="x") {
		title="付録等の一覧";
		page_ichi=-2;
	}
	else {
		title="近くの頁の見出";
		schstr= schstr.replace(/^\s*(.*?)\s*$/, "$1");	//trim spaces at both ends
		if ( g_vort_sw == "Nies") {
			if (romaji_check(schstr)) {
				//ローマ字なら、かなに変換
				schstr=romaji_seiri(schstr);
			}
			var kana=hiraganani_kaeru(schstr);
			page_ichi=page_mitukeru(kana);
		}
		else if ( g_vort_sw == "Esni") {
			if ( schstr.length > 1 ) {
				schstr=super_tukeru(schstr);	//x記法⇒字上符付き文字
//				document.getElementById("searchstr").value=schstr;
			}
			schstr=super_kaeru(schstr);			//字上符付き文字⇒x記法
			schstr=Al_majusklo(schstr);
			page_ichi=page_mitukeru(schstr);
		}
	}

	var frag= document.createDocumentFragment();

	//一覧のタイトル表示
	var div= makeResult("k", 0, title);
	frag.appendChild(div);

	//ページごとの仮名見出の一覧を作成
	var hajime, owari;
	if ( page_ichi==0 ) {
		//No list
		hajime=0;
		owari =0;
		page_ichi=1;
	}
	else if (page_ichi==-1) {
		//本文全ページ
		hajime=g_Data_start;
		owari =g_Data_end+1;
		page_ichi=1;
	}
	else if ( page_ichi==-2 ) {
		//補遺等
		hajime=g_Data_end+1;
		owari =g_Page_max;
		page_ichi=hajime+1;	//補遺・付録ページ最初
	}
	else {
		//目的ページの前後10ページ分
		var hajime=page_ichi-10;
		var owari =page_ichi+10;
		//範囲チェック
		if (hajime < g_Data_start) {
			hajime=g_Data_start; 
		}
		if (owari > g_Data_end+1) {
			owari=g_Data_end+1;
		}
	}

	var i;
	for (i=hajime; i<owari; ++i) {
		//0:kana_midasi,1:kana_key
		var page_data;					// [0]見出し,[1]キー
		if ( g_vort_sw == "Esni") {
			page_data=Esni_midasi[i];
		}
		else if ( g_vort_sw == "Nies") {
			page_data=Nies_midasi[i];
		}
		var n_page=i+1;
		var str_page;
		if (g_wholePage) {
			str_page=n_page.toString();
		}
		else {
			str_page= (Math.floor((n_page-1)/2) + 1).toString()	//1-2=>1, 3-4=>2,..
					+ ((n_page % 2==1)? "L":"R");				//odd=Left, even=Right
		}
		var kana_midasi=page_data[0];
//		var klass= (schstr!=" " && schstr!="x" && n_page==page_ichi)? "g":"r";
		var klass= "r";
		var div= makeResult(klass, str_page, kana_midasi);
		frag.appendChild(div);
	}
	results.appendChild(frag);

	//該当ページの本文画像を表示
	var str_page;
	var str_LR;
	if (g_wholePage) {
		str_page= page_ichi.toString();
		str_LR= "";
	}
	else {
		str_page= (Math.floor((page_ichi-1)/2)+1).toString();
		str_LR= (page_ichi % 2==1)? "L":"R";
		setPageLR(str_LR);
	}
	setPage(str_page);
	var img=document.getElementById("pageimg");
	img.src= pageImgFilename(str_page, str_LR);

	imageOnShow();
}


//見出し一項目DIV作成
//klass: "k"=ヘッダ, "r"=項目,"g"=項目(灰色)
//page : ページ番号("1"..)
//line : 表示文字列
function makeResult(klass, page, line) {
	var div= document.createElement("div");
	div.className=klass;
	div.setAttribute("params", page);
	var txt= document.createTextNode(line);
	div.appendChild(txt);
	return div;
}

/////
function getText(elem) {
	var ch=elem.firstChild;
	while (ch) {
		if (ch.nodeType==3)
			return ch.nodeValue;
		ch=ch.nextSibling;
	}
	return "(none)";
}
function setText(elem, text) {
	elem.innerHTML=text;
}

function isIE() {
	return (navigator.userAgent.indexOf("MSIE") >= 0);
}

function addEventHandler(elem, evtname, handler) {
	if (isIE())
		elem.attachEvent("on"+evtname, handler);
	else
		elem.addEventListener(evtname, handler, false);
}
function removeEventHandler(elem, evtname, handler) {
	if (isIE())
		elem.detachEvent(evtname, handler);
	else
		elem.removeEventListener(evtname, handler, false);
}


// 検索文字入力時
var o_inptimer=null;

function inputSearchStr(e) {

	var schstr= document.getElementById("searchstr").value;
	var evt;
	if (window.event) {
		evt= window.event;
	}
	else {
		evt= e;
	}
	var key= evt.keyCode;
	if (!key) {
		key= evt.charCode;	//for Firefox
	}

	var interval= 250;

// ★-->
	if (isIE()) {
		evt.returnValue=false;
		evt.cancelBubble=true;
	}
	else {
		evt.preventDefault();
		evt.stopPropagation();
	}
// <--★

	if (key==13) {
		//[Enter]
		if ( schstr.length == 0) {
			schstr= " ";
//(★)		document.getElementById("searchstr").value= " ";
		}

// ★-->
//		if (isIE()) {
//			evt.returnValue=false;
//			evt.cancelBubble=true;
//		}
//		else {
//			evt.preventDefault();
//			evt.stopPropagation();
//		}
// <--★
		interval= 10;
	}
//【要検討】ここから ★ まで、削除する方法
	else if ( ( key>96 && key<123 ) || key==32 || key==45 || key==39 ) {
		//'a'..'z' Space ' - (97:a 122:z 32:Space 39:' 45:-)
		schstr=schstr+String.fromCharCode(key);
	}
	else if (key>=65 && key<=90) {
		//'A'..'Z' -> 'a'..'z'
		schstr += String.fromCharCode(key+32);
	}
	else if ( ( key==8 ) || ( key==46 ) ) {
		//8:BS, 46:DEL
		if ( schstr.length > 1) {
			schstr=schstr.substring(0,schstr.length-1);
		}
		else {
			schstr="";
		}
	}
	var keta=schstr.length;
	if ( keta > 1) {
		if ( schstr.charAt(0) ==" " ) {
			schstr=schstr.substring(1,keta);
		}
	}
	document.getElementById("searchstr").value=schstr;
//	★ ここまで

	if (o_inptimer)
		clearTimeout(o_inptimer);
	o_inptimer= setTimeout(search, interval);
}


// ボタンのTip表示
var o_tips= {
	"prevpage":"前ページ",
	"nextpage":"次ページ",
	"zoomout":"画像縮小",
	"zoom1":"画像等倍",
	"zoomin":"画像拡大",
	"font_mal":"文字を縮小する",
	"font_egl":"文字を既定値にする",
	"font_grd":"文字を拡大する"
};

function showTip() {
	var evt;
	if (window.event)
		evt=window.event;
	else
		evt=arguments[0];

	var targetId= (isIE()? evt.srcElement: evt.target).id;
	var tip= o_tips[targetId];
	if (tip) {
		var elem=document.getElementById("tip");
		elem.style.left= (evt.clientX)+"px";
		elem.style.top= (evt.clientY+20)+"px";
		setText(elem, tip);
		elem.style.display="inline";
	}
}
function hideTip() {
	document.getElementById("tip").style.display="none";
}

// メッセージボックス
var o_timer;
var o_timecount;
function showMessageBox(msg) {
	var msgtext= document.getElementById("msgtext");
	msgtext.innerHTML=msg;
	var elem= document.getElementById("messagebox");
	elem.style.opacity="1.0";
	elem.style.filter="alpha(opacity=100)";
	elem.style.display="block";
	o_timecount=50;
	o_timer= setTimeout("blurMsgbox()", 100);
}

function closeMessageBox() {
	document.getElementById("messagebox").style.display="none";
	clearTimeout(o_timer);
}
function blurMsgbox() {
	--o_timecount;
	if (o_timecount==0) {
		closeMessageBox();
		return;
	}
	else if (o_timecount<=25) {
		var elem=document.getElementById("messagebox");
		elem.style.opacity=(o_timecount/25.0);
		var n= 100*o_timecount/25;
		elem.style.filter="alpha(opacity="+n+")";
	}
	o_timer= setTimeout("blurMsgbox()", 100);
}

//フォントの縮小・拡大 (ボタンイベント)

function font_granda() {
	changeFontSize(1);
}
function font_egala() {
	document.body.style.fontSize = g_StdFontSize+"pt";
//	document.getElementById("results").style.fontSize = g_ListFontSize+"pt";
}
function font_malgranda() {
	changeFontSize(-1);
}
function changeFontSize(incr) {
	var style= document.body.style;
	var strsize= style.fontSize;
	var newsize= ((/^\d+/.test(strsize))?
						parseInt(strsize) :
						g_StdFontSize)
					+ incr;
	if (newsize<g_MinFontSize || newsize>g_MaxFontSize) {
		showMessageBox("これ以上大きく/小さくできません。<br>(有効範囲: "+
g_MinFontSize+"～"+g_MaxFontSize+"pt)");
		return;
	}
	style.fontSize= newsize+"pt";

	// 一覧のフォントサイズ
//	style= document.getElementById("results").style;
//	strsize= style.fontSize;
//	newsize= ((/^\d+/.test(strsize))?
//						parseInt(strsize) :
//						g_ListFontSize)
//					+ incr;
//	style.fontSize= newsize+"pt";
}


//ページ、画像の表示

function pageImgFilename(page, pageLR) {
	if (page==0) {
		page=1;
		pageLR="L";
	}
	page=formatNumb(page, 4);
	if (!g_wholePage)
		page += pageLR;
	var filename= g_imgFilename.replace("#", page);
	return g_imgDir+"/"+filename;
}

function getPage() {
	var elem=document.getElementById("page");
	var v=removeZeros(elem.value);
	if (v.length==0) {
		v="1";
	}
	elem.value=v;
	return v;
}
function setPage(page) {
	//removeZeros(page);
	document.getElementById("page").value=page;
}
function setPageLR(lr) {
	document.getElementById("pLR").value= lr;
}

//[ページ]ボタン (button events)
function showPageImg() {
	showPage(0);
}

//ページ画像表示
//xxx: 現在のページ番号からの増分(0,+1,-1,+9)
function showPage(xxx) {
	var maxpages= (g_wholePage)? g_Page_max: g_Page_max/2;
	var elem=document.getElementById("page");
	var val=elem.value;
	val=removeZeros(val);
				//０８などの前ゼロは正しく数に変わらないから、前の０を取る
	var pageLR="";
	if (!g_wholePage)
		pageLR= document.getElementById("pLR").value;

	var page=0;
	if (val) {
		page=parseInt(val);
	}
	if (xxx==+9) {
		page=0;
		xxx=maxpages;
	}

	if (g_wholePage) {
		page=page+xxx;
	}
	else {
		if (xxx==1) {
			if (pageLR=="R") {
				++page;
				pageLR="L";
			}
			else {
				pageLR="R";
			}
		}
		else if (xxx==-1) {
			if (pageLR=="L") {
				--page;
				pageLR="R";
			}
			else {
				pageLR="L";
			}
		}
	}
	if (page<1) {
		page=1;
		pageLR="L";
	}
	if (page>maxpages) {
		showMessageBox("最終頁は " + maxpages + " です");
		page=maxpages;
		pageLR="R";
	}
	var page_str=fillZeros(page.toString(),4);
	setPage(page_str);//画面にページをセットするだけ
	if (!g_wholePage) {
		setPageLR(pageLR);
	}
	var src= pageImgFilename(page_str, pageLR);
	var img=document.getElementById("pageimg");
//	img.removeAttribute("src");
	img.src= src;
}


//-- Paging (button events) --
function showPrevPage() {
	showPage(-1);
}
function showNextPage() {
	showPage(+1);
}
function showFirstPage() {
	setPage("1");
	showPage(0);
}
function showLastPage() {
	showPage(+9);
}


//-- Scaling (button events) --
var o_curScale=g_defaultScale;	//[%] current scale
function scale() {
	var width= Math.floor(g_PageWidth*o_curScale/100);
	var height= Math.floor(g_PageHeight*o_curScale/100);
	var elem=document.getElementById("pageimg");
	elem.setAttribute("width", width+"px");
	elem.setAttribute("height",height+"px");
	//setText(document.getElementById("curscale"), Math.floor(o_curScale)+"%");
}
function enlarge() {
	o_curScale *= 1.1;
	scale();
}
function scale100() {
	var elem=document.getElementById("pageimg");
	o_curScale= g_defaultScale;
	scale();
}
function shrink() {
	o_curScale /= 1.1;
	scale();
}

//ページ番号を入力時
function inputPagePress(e) {
	var evt;
	if (window.event)
		evt= window.event;
	else
		evt= e;
	var key= evt.keyCode;
	if (!key)
		key= evt.charCode;	//for Firefox

	if (key==13) {			//Enter
		if (isIE()) {
			evt.returnValue=false;
			evt.cancelBubble=true;
		}
		else {
			evt.preventDefault();
			evt.stopPropagation();
		}
		//
		var elem=document.getElementById("page");
		var val=elem.value;
		var ppp=val.match(/^\d{1,3}$/);
		if (!ppp) {
			return;
		}
		//数字1～3桁入力あり
		//ppp=removeZeros(ppp);
		if (ppp=="0" || ppp=="") //0ページは1ページへ
			ppp="1";
		setPage(ppp);
		showPage(0);
	}
	else if (key!=8) {
		//Back_spaceキー以外のキーを押した時
		var elem=document.getElementById("page");
		var val=elem.value;
		if ( key>47 && key<58) {//数字キーを押した時
			//'0'..'9' (48:'0', 57:'9')
			key=key-48;
			val=val + key.toString();
		}
		var ppp=val.match(/^\d{4}$/);
		if (!ppp) {
			return;
		}
		//数字4桁入力
		var page_aa=removeZeros(ppp);
				//●●０８などの前ゼロは正しく数に変わらないから、前の０を取る
		var page_nn=parseInt(page_aa);
		var maxpages= (g_wholePage)? g_Page_max: (g_Page_max/2);
		if ( page_nn>g_Data_start && page_nn<(maxpages+1) ) {
			setPage(ppp);
			if (!g_wholePage)
				setPageLR("L");
			showPage(0);
		}
		else {
			showMessageBox("最終頁は "+maxpages+" です");
			if (!g_wholePage) {
				setPage(maxpages);
				setPageLR("R");
				showPage(0);
			}
		}
	}
}

//　見出し一覧の表示/隠し

// ▲一覧出す　△一覧隠す (ボタンイベント)
function showSearchPane() {
	var leftPane=document.getElementById("results");
	var rightPane=document.getElementById("imagepane");
	var fontBT=document.getElementById("font_buttons");
	if (leftPane.style.display=="none") {
		leftPane.style.width= g_ListWidth+"px";
		leftPane.style.display="block";
		rightPane.style.left= (g_ListWidth+12)+"px";
		setText(document.getElementById("btnshowsearchpane"), "▲一覧隠す");
		fontBT.style.display="inline";
	}
	else {
		leftPane.style.display="none";
		rightPane.style.left="5px";
		setText(document.getElementById("btnshowsearchpane"), "△一覧出す");
		fontBT.style.display="none";
	}
	setPagingClickRange();
}

//本文画像ペインを表示する
//(画像が隠れている場合でも、選択すれば画像を表示するため)
function imageOnShow() {
	var leftPane=document.getElementById("results");
	var rightPane=document.getElementById("imagepane");
	if (rightPane.style.display=="none") {
		leftPane.style.display="block";
		leftPane.style.width= g_ListWidth+"px";
		rightPane.style.left= (g_ListWidth+12)+"px";
		rightPane.style.display="block";
//		setText(document.getElementById("btimgshow"), "★画像隠す");
	}
}




// かな見出から、ソート・順番比較用のかなキーを作成する
// 濁音から対応の清音を作り、後ろへ順位付けの数字を付与する

function hiraganani_kaeru(mojiretu) {
	var mmm;
	var kana_sw;
	var moji, chooon, kana, kigoo;

	var out_kana  = "";
	var out_kigoo = "";
	var mae_moji  = "*";
	var in_paren  = false;	//括弧の中ならtrue

	var keta_max = mojiretu.length;
                         // 文字があるときのみ処理する
	for ( mmm = 0; mmm<keta_max; ++mmm) {

		if ( keta_max==1) {
			moji = mojiretu;
		}
		else {
			moji = mojiretu.charAt(mmm);
		}


		kana_sw = kana_check(moji);

		if ( kana_sw[0] != "N" && kana_sw[1] != "N" ) {
			//かな変換OK
			kana  = kana_sw[0];
			kigoo = kana_sw[1];
		}
		else if ( moji == "ー" && mmm > 0 ) {
			//長音記号は母音(あいうえお)に変換
			kana = katakana_choon_henkan(mae_moji);
			kigoo  = "3";
		}
		else if ( moji == "・" || moji == "("  || moji == ")" )  {
			//(特殊)
 			kigoo  = "8";
		}
		else {
			//エラー
			kigoo  = "9";
		}

		if ( !in_paren && moji == "(" )  {
			//括弧開始
			in_paren = true;
		}
		else if ( in_paren && moji == ")" )  {
			//括弧終了
			in_paren = false;
		}
		
		if ( kigoo == "9" )  {
			var S = "見出かな変換ーエラー =" + moji + "=mae=" + mae_moji;
			out_kigoo = out_kigoo;
		}
		else if  ( !in_paren && moji != ")" ) {
			//OK,出力に追加していく。ただし(..)の中なら追加しない。
			//NOTE !! moji=="・" kigoo==8のときkana?
			out_kana  = out_kana  + kana;
			out_kigoo = out_kigoo + kigoo;
		}
		
		mae_moji  = kana;
	}
	return out_kana + out_kigoo;
}

// ひらがなに残った、カタカナの長音『 ー 』を該当のひらがなに変える

function katakana_choon_henkan(moji) {
	if      ("あぁかがさざただなはばぱまやらわ".indexOf(moji)>=0)
		return "あ";
	else if ("いぃきぎしじちぢにひびぴみゃりょ".indexOf(moji)>=0)
		return "い";
	else if ("うぅくぐすずつづぬふぶぷむゆる".indexOf(moji)>=0)
		return "う";
	else if ("えぇけげせぜてでねへべぺめゅれ".indexOf(moji)>=0)
		return "え";
	else if ("おぉこごそぞとどのほぼぽもよろ".indexOf(moji)>=0)
		return "お";
	else {
		var S = " かたかな長音変換エラー　ありえない=" + moji + "=";
		alert("780 " + S);
		return "";
	}
}

// ひらがなのとき 濁音等なしのひらがなと 0 1 2 を返す
// カタカナ の時　濁音等でないひらがなと 0 1 2 を返す
// 『・』『 ( ) 』はそれと 9 、その他は NN を返す

function kana_check(moji) {
	var AK, BK, CK;
	AK =      "アイウエオカキクケコサシスセソタチツテト";
	AK = AK + "ナニヌネノハヒフヘホマミムメモヤユヨラリ";
	AK = AK + "ルレロワンヲ";
	AK = AK + "ガギグゲゴザジズゼゾダヂヅデドバビブベボヴ";
	AK = AK + "がぎぐげござじずぜぞだぢづでどばびぶべぼ";
	AK = AK + "パピプペポッァィゥェォャュョ";
	AK = AK + "ぱぴぷぺぽっぁぃぅぇぉゃゅょ";

	BK =      "あいうえおかきくけこさしすせそたちつてと";	// 0..19
	BK = BK + "なにぬねのはひふへほまみむめもやゆよらり";	//20..39
	BK = BK + "るれろわんを";								//40..45

	CK =      "かきくけこさしすせそたちつてとはひふへほう";	//46..66
	CK = CK + "かきくけこさしすせそたちつてとはひふへほ";	//67..86
	CK = CK + "はひふへほつあいうえおやゆよ";				//87..100
	CK = CK + "はひふへほつあいうえおやゆよ";				//101..114

	var ichi= BK.indexOf(moji);	//0..45,-1
	if (ichi<0) {
		ichi= AK.indexOf(moji);	//0..114,-1
	}

	var out_moji = "N";
	var out_kigoo;
	if ( ichi < 0 ) { 
		out_moji  = "N";
		out_kigoo = "N";
	}
	else   {
//		if ( ichi < 115 ) {
			out_moji = (BK+CK).charAt(ichi);
//		}
//		else {
//			out_moji = moji;
//		}

		if ( ichi < 46  ) {
			out_kigoo = "0";	//清音
		}
		else if ( ichi < 87  ) {
			out_kigoo = "1";	//濁音
		}
		else if ( ichi < 115 ) {
			out_kigoo = "2";	//半濁音、小かな
		}
		else {
			out_kigoo = "9";	//?
		}
	}
	return [ out_moji, out_kigoo];
}

//検索文字列(+文字種別付き)から、該当ページを探す
//引数 kana:ひらがな文字列+文字種別(0:清音 1:濁音 2:半濁音・拗音 3:カタカナの長音記号)
//戻り値: ページ番号 1..g_Data_end+1, 0=Not found
function page_mitukeru(kana) {
	var midasi;
	if (g_vort_sw=="Esni")
		midasi= Esni_midasi;
	else if (g_vort_sw=="Nies")
		midasi= Nies_midasi;
	else
		return 0;

	var i=g_Data_start;	//=0
	for ( ; i<=g_Data_end; ++i) {
		//0:kana_midasi,1:kana_key
		var page_data= midasi[i];
		var kana_key=page_data[1];
		if ( kana_key > kana) {
			return i;	//ひとつ手前のページになる
		}
	}
	return i;	//=g_Data_end+1
}

/*
//(現在未使用, 定数未定義)
function changeVortaro() {
	//初期値　g_vort_sw = "Esni";
	if ( g_vort_sw == "Nies") {
		g_vort_sw  = Esni_gvort_sw;
		g_vortaro  = Esni_gvortaro;
		g_vortaro_color= Esni_gfnc;
		g_Data_start = Esni_Data_start;
		g_Data_end   = Esni_Data_end;
		g_Page_max   = Esni_Page_max;
		g_PageWidth  = Esni_PageWidth;
		g_PageHeight = Esni_PageHeight;
		g_imgDir		= Esni_imgDir;
		g_imgFilename	= Esni_imgFilename;
		g_defaultScale	= 100; //2089/1531;
	}
	else {
		g_vort_sw  = Nies_gvort_sw;
		g_vortaro  = Nies_gvortaro;
		g_vortaro_color= Nies_gfnc;
		g_Data_start = Nies_Data_start;
		g_Data_end   = Nies_Data_end;
		g_Page_max   = Nies_Page_max;
		g_PageWidth  = Nies_PageWidth;
		g_PageHeight = Nies_PageHeight;
		g_imgDir		=Nies_imgDir;
		g_imgFilename	=Nies_imgFilename;
		g_defaultScale	= 45; //1531/2089;
	}
	var elem= document.getElementById("vort_namae");
	elem.innerHTML =g_vortaro;
	elem.style.color= g_vortaro_color;
}
*/

//x記法から字上符付き文字に変換する
function super_tukeru(str) {
	var table={	'c':'ĉ', 'g':'ĝ', 'h':'ĥ', 'j':'ĵ', 's':'ŝ', 'u':'ŭ',
				'C':'Ĉ', 'G':'Ĝ', 'H':'Ĥ', 'J':'Ĵ', 'S':'Ŝ', 'U':'Ŭ'};
	var outstr="";
	for (var i=0; i<str.length; ++i) {
		var c= str.charAt(i);
		if (c=='x' || c== 'X') {
			var len= outstr.length;
			var prev= (len>0)? outstr.charAt(len-1) : '';
			var cc= table[prev];
			if (cc) {
				outstr= outstr.substring(0, len-1) + cc;
			}
			else {
				outstr += c;
			}
		}
		else {
			outstr += c;
		}
	}
	return outstr;
}

//字上符付き文字をx記法に変換して返す
function super_kaeru(mojiretu) {
	var keta_max=mojiretu.length;
	var outstr="";
	for ( mmm = 0; mmm<keta_max; ++mmm) {
		var amoji=mojiretu.charAt(mmm);
		var i;
		for ( i = 0; i<Sup_moji.length; ++i) {
			var super_hairetu = Sup_moji[i];
			super_moji = super_hairetu[0];
			var x_moji = super_hairetu[1];
			if (amoji==super_moji) {
				amoji=x_moji;
				break;
			}
		}
		outstr=outstr+amoji;
	}
	return outstr;
}

//小文字に変換
function Al_minisklo(mojiretu) {
	return mojiretu.toLowerCase();
}

//大文字に変換 (ただしXは小文字xに)
function Al_majusklo(mojiretu) {
	var outstr= mojiretu.toUpperCase();
	return outstr.replace("X", "x");
}

//文字列すべてa..z ' - spaceならtrue, それ以外の文字があればfalseを返す
function romaji_check(mojiretu) {
	mojiretu=super_kaeru(mojiretu);
	return (/^[a-z '\-]+$/i).test(mojiretu);
}

//母音aiueoなら、そのひらがなを返す。母音でないなら、falseを返す
function boin_check(mj) {
	var mmm;
	for ( mmm = 0; mmm<5; ++mmm) {
		var data = Boinretu[mmm];
		var romaji=data[0];
		var kana=data[1];
		if ( mj==romaji ) {
			return kana;
		}
	}
	return false;
}

//子音(b..z)ならRom_Hira[]の位置indexを返す。子音でないなら、nullを返す
function siin_check(mj) {
	var mmm;
	for (mmm=0; mmm<Siinretu.length; ++mmm) {
		var data  = Siinretu[mmm];
		var romaji= data[0];
		var loko  = data[1];
		if ( mj==romaji ) {
			return loko;
		}
	}
	return null;
}

//拗音など(二重子音)ならRom_Hira[]の位置indexを返す。それ以外はnullを返す
function dabri_check(mojiretu) {
	var mmm;
	for (mmm=0; mmm<Dabrretu.length; ++mmm) {
		var data  = Dabrretu[mmm];
		var romaji= data[0];
		var loko  = data[1];
		if ( mojiretu==romaji ) {
			return loko;
		}
	}
	return null;
}

//一音節のローマ字を,かな文字に変換。変換不可ならローマ字列を返す
//引数 hairetu:[0]ローマ字列, [1]Rom_Hira[]のindex
function moji_set(hairetu) {
	var mojiretu=hairetu[0];
	var hajime  =hairetu[1];
	var mmm  =hajime-1;
	var owari=mmm+5; //hajime+5とすると文字列の結合となってしまう
	while ( mmm < owari) {
		++mmm;
		var data  = Rom_Hira[mmm];
		var romaji= data[0];
		var kana  = data[1];
		if ( mojiretu==romaji ) {
			return kana;
		}
	}
	return mojiretu;
}


//ローマ字列をひらがな列に変換して返す
function romaji_seiri(mojiretu) {
	var Delimiters="\'- ";	//音節区切り文字
	var out="";
	var keta_max=mojiretu.length;
	mojiretu= mojiretu.toLowerCase();
	for (var z=0; z < keta_max; ++z) {
		var amj=mojiretu.charAt(z);
		if (Delimiters.indexOf(amj)>=0 && !(z==0 && amj==' ')) {
			//音節区切りを読み跳ばす。ただし、先頭の空白は有効
			continue;
		}

		var bmj;
		if ( z+1 < keta_max) {
			bmj=mojiretu.charAt(z+1);
			if (Delimiters.indexOf(bmj)>=0)
				bmj='';
		}
		else { 
			bmj='';
		}

		var cmj;
		if ( z+2 < keta_max) {
			cmj=mojiretu.charAt(z+2);
			if (Delimiters.indexOf(cmj)>=0)
				cmj='';
		}
		else { 
			cmj='';
		}

		var Hs;
		if ( boin_check(amj) ) {
			//(単)母音
			Hs=boin_check(amj);
		}
		else if ( boin_check(bmj) ) {
			//子音+母音
			var siin_loko=siin_check(amj);
			var hairetu=[amj+bmj, siin_loko];
			Hs=moji_set(hairetu);
			z=z+1;
		}
		//#####################################################
		else {
			//子音(＋子音)の時
			var abmj=amj+bmj;
			var dabri_loko=null;
			if (bmj=="y" || bmj=="h" || bmj=="w" || bmj=="s" || abmj=="lt") {
				dabri_loko=dabri_check(abmj);
			}

			if ( dabri_loko != null ) {
				//拗音などの二重子音
				if ( z+2 < keta_max ) {
					//3文字目あり
					if ( boin_check(cmj) ) {
						//子音+子音+母音
						var hairetu=[amj+bmj+cmj, dabri_loko];
						Hs=moji_set(hairetu);
						z=z+2;
					}
					else {
						//子音子音＋母音でない
						Hs=abmj;
					}
				}
				else {
					//3文字目なし
					Hs=abmj;
					z=z+1;
				}
			}
			else if ( amj=="n" ) {
				Hs="ん";
				if ( bmj=='n' && (cmj=='y' || cmj=='n' || cmj=='' || boin_check(cmj)) ) {
//					&& g_test.indexOf("!nn")<0 ) {
					//"nn" + cmj=='y' (ん+や行)
					//"nn" + cmj=='n' (ん+な行文字)
					//"nn" + 語末
					//"nn" + cmj==母音 → ん+(あ～お) 例 onna-> onn-a おんあ
					z=z+1;
				}
				//else {
					//単語末のn または nの後が子音(angai⇒あんがい)
				//}
			}
			else if ( abmj=="mm" || abmj=="mb" || abmj=="mp") {
				//例 sammyaku→さんみゃく, simbun→しんぶん, kempou→けんぽう
				Hs="ん";
			}
			else if ( amj==bmj || abmj=="tc") {
				//促音 (ss, kk, tc[h] など)
				Hs="っ";
				if ( z+2 == keta_max ) {
					//2文字目が最終なら、読み跳ばして終了
					z=z+1;
				}
			}
			else {
				//先頭の空白,xは OK
				//その他の子音列は(例 kr, sk)エラー
				Hs=amj;
			}
		//##########################################################
		}

		out=out+Hs+"";
	}//while fin
	return out;
}

// imgpageでのマウスポインタ設定 ←＋→
function Img_OnMouse_move(evt) {
	var target;
	if (window.event) {
		evt= window.event;
		target= window.event.srcElement;
	}
	else {
		target= evt.target;
	}

	if (evt.clientX <= o_x_prev) {
		target.style.cursor= 'url(sistem_img/PagePrev.gif),url(sistem_img/PagePrev.cur),w-resize';
	}
	else if (evt.clientX >= o_x_next) {
		target.style.cursor= 'url(sistem_img/PageNext.gif),url(sistem_img/PageNext.cur),e-resize';
	}
	else {
		target.style.cursor= "default";	//"move";
	}
}

// 本文画像ペインをクリック時, 前/次ページを表示
function Img_OnMouse_down(evt) {
	if (window.event)
		evt= window.event;

	if (evt.clientX <= o_x_prev) {
		showPage(-1);
	}
	else if (evt.clientX >= o_x_next) {
		showPage(+1);
	}
	if ( g_test=="xy_test_yes" ) {
		alert("マウスを押した x 座標=" + evt.clientX);
	}
}

//[クリア]ボタンをクリック時
function search_str_clear() {
	document.getElementById("searchstr").value="";
	document.getElementById("searchstr").focus();
}

